# 2017 Western Passage Tidal Energy Resource Characterization Measurements

These data are from tidal resource characterization measurements
collected between April and July 2017 in Western Passage near
Eastport, Maine, USA.

The dataset contains the following four sub-datasets, each of which
is described in more detail below:

1. A bottom-mounted Teledyne RDI Workhorse 600 kHz acoustic Doppler
   current profiler (ADCP) was deployed at 44.92015°N, 66.98915°W in
   ~50 m of water from 3 April – 18 July (106 days). Data were 
   recorded in 6-minute increments in the ENU (East, magnetic North,
   Up)coordinate system with bin-mapping enabled.

2. A bottom-mounted Nortek Signature 500 kHz ADCP was deployed at
   44.92192°N, 66.98913°W in ~50 m of water from 4 April – 18 July
   (105 days). Data were sampled and recorded at 2 Hz and recorded in
   the ENU (East, magnetic North, Up) coordinate system.

3. Between those stations along a cross-channel transect, a Stable
   Tidal Turbulence Mooring (STTM) positioned ~10 m above the seabed
   was deployed for one week during a spring tide. The STTM was
   outfitted with two Nortek Vector acoustic Doppler velocimeters
   equipped with inertial motion units (ADVs), a bottom-tracking
   downward-looking Teledyne RDI Workhorse 600 kHz ADCP to provide
   motion-corrected flow and turbulence characteristics at high
   temporal resolution, and an upward-looking Teledyne RDI Sentinel
   V20 ADCP. The STTM was deployed at 44.92098°N, 66.98922°W from
   24-31 May.

4. A vessel-mounted Teledyne RDI Workhorse 300 kHz ADCP
   collected current data along three transects
   over two days, 4-5 April.

The data processing used [DOLfYN version
0.11.2](https://github.com/lkilcher/dolfyn/releases/tag/0.11.2).
All hdf5 files (i.e., files ending in `.h5`) contained here can be
opened using that version of DOLfYN (e.g., `dat =
dolfyn.load('<filename.h5>')`).

All distances are in meters (e.g., depth, range, MLLW, hab, eta, z_),
and all velocities in m/s. See the DOLfYN
[documentation](https://lkilcher.github.io/dolfyn/), and/or the Nortek
and Teledyne RDI documentation for additional details.

## Reproducing the data processing

The scripts that were used to process the data from the source files
to the processed files are included in the
`wp2017_processing.zip` file. This is included for several
reasons:

- in case users of the data need to modify the data processing

- as a complete log of what was done to generate the data

- as an example guide for using DOLfYN to process this or similar datasets.

If you wish to reproduce the data processing, follow these steps:

1. Unzip the files in `wp2017_processing.zip` into the same
   folder that contains all of the data files (all files should be in
   one folder).

2. Install DOLfYN and its dependencies:

        pip install -f requirements.txt

3. From here you have two options:
   - Run the `process_<sub dataset>.py` scripts individually, or
   - Run the `run_tests.py` script to run all of the scripts in
     sequence, write the data out to a `tmp/` folder, and compare the
     data to the original data files (i.e., confirm that running the
     processing on your machine generates the same data as contained
     in the public dataset).


## Bottom-Mounted RDI Workhorse 600

The bottom-mounted upward looking Teledyne RDI Workhorse 600 kHz ADCP
data from a stationary survey in the Western Passage, on the border of
Maine, USA, and New Brunswick, Canada. The data was collected
continuously from April 3, 2017 to July 18, 2017. The station location
is 44.92015°N, 66.98915°W.

Data were recorded in 6-minute increments in the ENU (East, magnetic
North, Up) coordinate system with internal bin mapping enabled. Each
velocity data point is the average of 60 pings where the sampling
frequency of each ping was 1 sample/6 seconds (0.166 Hz). The data was
collected in Maine local time (UTC-4) and so the source data file
(ending `.000`) are in that timezone, but all other files have been
adjusted to UTC.

### Workhorse 600 Data File Description

The following files are from this instrument:

#### Source Data File

- `WP2017_Bottom_RDI600.000` is the raw/source RDI ADCP file. See the RDI
    documentation for details on this file format.

#### DOLfYN/HDF5 Files

- `WP2017_Bottom_RDI600_raw_ETU_d112.h5` contains all data in the
  `.000` file, is corrected for magnetic declination, and the
  timestamps are adjusted from UTC-4 to UTC.

- `WP2017_Bottom_RDI600_cln_ETU_d112.h5` contains the data after
  cleaning, calculating mean lower low water (MLLW), depth relative to MLLW, and sea surface
  height relative to MLLW.

#### Zipped CSV Files

- The `.csv.zip` file is the processed data in a set of csv files that
  have been zipped together into a single file. The `.csv.zip` file
  contains:

    - `WP2017_Bottom_RDI600.EAST.csv`, true eastward velocity component,
    units: m/s. Columns are depth bins relative to observed MLLW, with
    the headers indicating the depth in m. Rows are timesteps.

    - `WP2017_Bottom_RDI600.NORTH.csv`, true northward velocity
    component. Format the same as `.EAST.csv`
    
    - `WP2017_Bottom_RDI600.UP.csv`, up velocity component, units:
      m/s. Format the same as `.EAST.csv`
    
    - `WP2017_Bottom_RDI600.ERROR.csv`: RDI-defined error velocity,
      units: m/s. Format the same as `.EAST.csv`
    
    - `WP2017_Bottom_RDI600.INFO.csv`: Distance to the center of each
    bin from the RDI face (`range_m`), water depth above the seabed
    (`depth_m`), temperature measured at the RDI head in degrees C
    (`temp_C`).

### Workhorse 600 Data Processing

The `.csv.zip` file and `.h5` files were created using the
`process_btmWkhs.py` script. See that script for a complete
description of what has been done, but a summary is:

- Timestamp has been modified from UTC-4 to UTC

- Orientation of the instrument has been updated to include magnetic
  declination

- DOLfYN-defined heading, pitch, and roll values have been added to
  dat.orient, while instrument-defined heading, pitch, and roll can be
  found in dat.orient.raw

- Data has been cropped to eliminate samples collected before and
  after the instrument was on the seabed

- Data has been cleared (i.e., "NaN'd") where signal correlation < 64
  and the sum of the percent of good 3-beam and 4-beam solutions < 90

- MLLW has been calculated from the observed timeframe

- Sea surface height relative to observed MLLW has been calculated

- Data has been cleared (i.e., "NaN'd") below 90% of the water depth

- Velocity data has been cleared (i.e., "NaN'd") for the duration of
  the observed timeframe for any range bin without *good* data (i.e.,
  not "NaN'd") in at least 95% of the time events

## Bottom-Mounted Nortek Signature 500

The bottom-mounted upward looking Nortek Signature 500 kHz AD2CP data
was collected in the Western Passage, on the border of Maine, USA, and
New Brunswick, Canada. The data was collected continuously from April
4, 2017 to July 18, 2017. The station location is 44.92192°N,
66.98913°W

Data were sampled and recorded at 2 Hz and recorded in the ENU (East,
magnetic North, Up) coordinate system. The timestamps are in UTC.

DOLfYN (as of version 0.11.2) does not have a bin mapping function,
therefore Nortek's Ocean Contour software has been used to import the
raw `WP2017_Bottom_Sig500.ad2cp`, process it into 5-minute
means, and output the MATLAB files described in the next section.

The following selections have been made in the Processing Wizard of
the Ocean Contour software:

- "Transforms/Corrections":ENU velocity, bin mapping, magnetic
  declination = -16.74, surface pressure offset (dbar) = 0

- "Data Selection": Side Lobe Interference (%) = 90, Min. Amplitude
  (dB) = 30, Min. Correlation (%) = 50.

- "Averaging Parameters": 5-minute means created by setting the
  averaging window to 600 (samples), percent good threshold to 50%
  (meaning a 5-minute mean has only been made if at least 300 of the
  600 samples are "good").

The slanted and 5th beam 5-minutes means generated by Ocean Contour
have been exported as MATLAB .mat files. When the data was examined in
Ocean Contour, two chunks of time when the quality of the velocities
was good (i.e., the data range in the water column was good) and the
instrument attitude were fairly steady were identified:

1. The first chunk ranges from May 1 00:00:00 to May 26 00:00:00 with
   heading ~105, pitch 12-15, roll -10 degrees.

2. The second chunk ranges from June 3 12:00:00 - June 23 00:00:00
   with heading ~96, pitch 11, roll -6.7 degrees.

### Signature 500 Data Files

#### Source File

- `WP2017_Bottom_Sig500.ad2cp` is the source data file for the bottom-mounted signature.

#### MATLAB Files

- `WP2017_Bottom_Sig500_OceanContour_Burst.VTC.DSEL_binmap.AVER.mat`
      is the MATLAB file of 5-minute means of data from the 4 slanted
      beams on the bottom-mounted Nortek Signature 500 kHz ADCP
      generated in Nortek's Ocean Contour software. Data are in the
      ETU coordinate system (East, True North, Up).

- `WP2017_Bottom_Sig500_OceanContour_IBurst.DSEL.AVER.mat` is the
      MATLAB file of 5-minute means of data from the vertical beam on
      the bottom-mounted Nortek Signature 500 kHz ADCP generated in
      Nortek's Ocean Contour software.

#### DOLfYN/HDF5 Files

- `WP2017_Bottom_Sig500_OceanContour_masked_d112_ETU.5min.h5` contains
  5-minute means of the bottom-mounted Nortek Signature 500 kHz ADCP
  data exported from Ocean Contour software and the air pressure from
  the NDBC `.mat` file after being imported into DOLfYN, where NaNs
  replaced the "bad" Nortek Signature 500 data and water depth was
  calculated from the air pressure and the pressure measurement at the
  ADCP.

- `WP2017_Bottom_Sig500_OceanContour_May_d112_ETU.5min.h5` is the May
  1-26 subset of `Sig500_5min_means_OceanContour_masked_d112_ETU.h5`,
  with velocity bins cropped to include only bins with good data 95%
  of the time, and the calculation of MLLW, depth relative to MLLW,
  and sea surface height relative to MLLW.

- `WP2017_Bottom_Sig500_OceanContour_June_d112_ETU.5min.h5` is the
  June 3-23 subset of
  `Sig500_5min_means_OceanContour_masked_d112_ETU.h5`, with velocity
  bins cropped to include only bins with good data 95% of the time,
  and the calculation of MLLW, depth relative to MLLW, and sea surface
  height relative to MLLW.

#### Zipped CSV Files

- The `.csv.zip` file is the processed data in a set of csv files that
  have been zipped together into a single file. The `.csv.zip` file
  contains:

  - `WP2017_Bottom_Sig500.EAST.csv`, true eastward velocity component,
  units: m/s. Columns are depth bins relative to observed MLLW, with
  the headers indicating the depth in m. Rows are timesteps.
  
  - `WP2017_Bottom_Sig500.NORTH.csv`, true northward velocity
  component. Format the same as `.EAST.csv`
  
  - `WP2017_Bottom_Sig500.UP1.csv`, up velocity component calculated
  from one pair of slanted beams, units: m/s. Format the same as
  `.EAST.csv`
  
  - `WP2017_Bottom_Sig500.UP2.csv`: up velocity component calculated
  from the other pair of slanted beams. Format the same as `.EAST.csv`

  - `WP2017_Bottom_Sig500.INFO.csv`: Distance in meters to the center
  of each bin from the Signature face (`range_m`), water depth above
  the seabed (`depth_m`)

### Signature 500 Data Processing

The `.csv.zip` files and `.h5` files were created using the
`process_btmSig500.py` script. See that script for a complete
description of what has been done. A summary is:

- The .mat files of 5-minute means Ocean Contour software have been
  loaded and select variables have been added to a DOLfYN data
  structure

- Water depth above the Signature has been calculated using the
  Signature's pressure data and atmospheric pressure measured at a
  nearby NDBC station

- DOLfYN-defined heading, pitch, and roll values have been added to
  dat.orient, while instrument-defined heading, pitch, and roll can be
  found in dat.orient.raw

- Data has been cleared (i.e., "NaN'd") with the mask Ocean Contour
  processing steps identified as "bad"

- May and June data subsets have been created. Within each subset

  - Data has been cleared (i.e., "NaN'd") for the duration of the
  observed timeframe for any range bin without "good" data (i.e., not
  "NaN'd")in at least 95% of the time events

  - MLLW has been calculated from the observed timeframe

  - Sea surface height relative to observed MLLW has been calculated

## Stable Tidal Turbulence Mooring

The Stable Tidal Turbulence Mooring (STTM) was deployed in the Western
Passage, on the border of Maine, USA, and New Brunswick, Canada. The
data was collected continuously from May 24, 2017 to May 31, 2017. The
station location is 44.92098°N, 66.98922°W .

The STTM is broadly described in [Kilcher
et.al. 2016](https://doi.org/10.2172/1244672) and [Harding
et.al. 2017](https://doi.org/10.1175/JTECH-D-16-0189.1). The
StableMoor buoy for this project is approximately 3.5 m long with a
main body diameter of 0.5 m, tail ring maximum diameter of 0.75 m,
wingspan of 1.5 m, a nominal weight in air of 650 kg, and seawater
buoyancy of 185 kg and was produced by DeepWater Buoyancy, Biddeford,
Maine, USA.

The STTM was outfitted with two Nortek Vector acoustic Doppler
velocimeters equipped with inertial motion units, a bottom-tracking
downward-looking Teledyne RDI Workhorse 600 kHz ADCP to provide
motion-corrected flow and turbulence characteristics at high temporal
resolution, and an upward-looking Teledyne RDI Sentinel V20 ADCP.

- A Nortek Vector sensor head was mounted to the end of each ‘wing’ in
  an upward facing direction and the Vector bodies were mounted
  vertically in wells in the StableMoor. Vectors sampled continuously
  at 16 Hz.

- One downward-looking Teledyne RDI Workhorse 600 kHz ADCP. Data were
  sampled at 2 Hz and recorded the mean of 3 samples in 1.5-second
  increments (for an effective sampling rate of 0.66 Hz) in the ENU
  (East, magnetic North, Up) coordinate system with bin mapping
  enabled.

- One upward-looking Teledyne RDI Sentinel V20 1000 kHz ADCP. Data
  were recorded at 0.4 Hz and collected in beam coordinates.

The timestamps are in UTC. 

### STTM Data Files

#### Source Data Files

- `WP2017_STTM_ADVport.VEC` is the source file from the STTM’s port
  Nortek Vector.

- `WP2017_STTM_ADVstbd.VEC` is the source file from the STTM’s starboard
  Nortek Vector.

- `WP2017_STTM_RDI.000` is the source file from the STTM's
  downward-looking RDI Workhorse 600 kHz ADCP. See the RDI
  documentation for details on this file format.

- `WP2017_STTM_V20.pd0` is the source file from the STTM'S upward-looking
  Teledyne RDI Sentinel V20 ADCP.

#### MATLAB Files

- `WP2017_STTM_v20.mat` is the MATLAB .mat file saved after reading in
  `WP_SMB02_V20_May2017.pd0` using the `rdradcp` function from
  RDADCP_Jan18v0 at https://www.eoas.ubc.ca/~rich/#RDADCP. Data are in
  beam coordinates. The velocity data need bin mapping and motion
  correction, neither of which has been done. Here, the only data used
  is the depth data; it is used to calculate the STTM’s height above
  the bottom.

#### DOLfYN/HDF5 Files

- `WP2017_STTM_ADVport_read_from_VEC_INST_d112.h5` is the port ADV
  data from file `WP2017_STTM_ADVport.VEC`, plus: defining parameters
  needed for motion correction, and updating the orientation matrix
  for magnetic declination. Data are in the instrument coordinate
  system.

- `WP2017_STTM_ADVstbd_read_from_VEC_INST_d112.h5` is the starboard
  ADV data from file `WP2017_STTM_ADVstbd.VEC`, defining parameters
  needed for motion correction, and updating the orientation matrix
  for magnetic declination. Data are in the instrument coordinate
  system.

- `WP2017_STTM_ADVstbd_clnETU_d112.h5` contains the starboard ADV data
  after cropping and cleaning the data following the Goring and Nikora
  (2002) despiking method, with Wahl (2003) correction.

- `WP2017_STTM_ADVstbd_d112_w_ulow_waterdepth_ETU.h5` contains the
  starboard ADV data after motion correcting and calculating the low frequency translational
  motion of the STTM recorded by the STTM’s downward-looking RDI
  Workhorse 600 kHz ADCP in order to fully motion correct the STTM’s
  starboard Nortek Vector velocity data, and calculating MLLW.

- `WP2017_STTM_ADVstbd_d112_ETU_5min.h5` is the starboard ADV data
  after calculating 5-minute means and turbulence statistics.

- `WP2017_STTM_RDI_read_from_000_ETU_d112.h5` contains the data in
  `WP2017_STTM_RDI.000` and corrected for magnetic declination.

- `WP2017_STTM_RDI_timesynced2ADVs_clnETU_d112.h5` contains the STTM’s
  downward-looking Teledyne RDI Workhorse 600 kHz ADCP data saved
  after syncing the Workhorse time stamp to the starboard Nortek
  Vector time stamp.

- `WP2017_STTM_RDI_d112_5min_ETU.h5` contains the 5-minute means of
  the vertically binned velocity data from the STTM’s downward-looking
  Teledyne RDI Workhorse 600 kHz ADCP.

#### CSV Files

- `WP2017_STTM_ADVstbd_corrected_RDI_time_1H_Bins.csv` This is the
    time correlation data between the Starboard ADV and the
    down-looking ADCP on the STTM.

- `WP2017_STTM_ADVstbd_d112_ETU_5min.csv` This is the 5-minute
    averaged starboard ADV data. Rows are timesteps, columns are:
    
    - `East vel [m/s]`: true eastward velocity component
    - `North vel [m/s]`: true northward velocity component
    - `Up vel [m/s]`: upward velocity component
    - `Horizontal Velocity Mag. [m/s]`: horizontal velocity magnitude
    -  `water depth [m]`: full water column depth at the STTM station
    - `height above bottom [m]`: height of the STTM above the seabed
    - `depth below surface [m]`: depth of the STTM below the water surface
    - `Turbulence Intensity [-]`: turbulence intensity calculated
    using horizontal velocity magnitude and with Doppler noise
    removed, units: nondimensional
    - `u'u' [m^2/s^2]`: East component of TKE
    - `v'v' [m^2/s^2]`: North component of TKE
    - `w'w' [m^2/s^2]`: Up component of TKE
    - `Temperature [C]`: water temperature measured at the end bell of
    the Vector


### STTM Data Processing

See the `process_STTM.py` script for a complete description of the
data processing that generated the `.csv` and `.h5 files. A summary
is:

- Raw files have been imported from the starboard Vector and the
  STTM's downward-looking RDI Workhorse

- Raw files have been read, cropped, cleaned, and .h5 files have been
  saved in ETU coordinates

- The starboard Vector and STTM's downward-looking RDI Workhorse
  timestamps have been time synced. Done externally then imported
  here.

- The starboard Vector data has been motion corrected following the
  method described in [Kilcher
  et.al. 2017](https://doi.org/10.1175/JTECH-D-16-0213.1)

- The 'rotational' motion of STTM's downward-looking RDI Workhorse's
  head has been calculated and added to datADVs.orient as 'ulow_rot'

- The 0.66 Hz RDI bt\_vel and bt\_range have been interpolated up to
  16 Hz to match the datADVs data and named
  `datADVs.orient['ulow_bt']` and 
  `datADVs.orient['ulow_bt_range']`. The low frequency motion of the
  STTM has been calculated as
  `datADVs.orient['ulow'] = low pass filter (datADVs.orient['ulow_bt'] + datADVs.orient['ulow_rot'])`. 
  `datADVs.props['rotate vars']` have
  been updated to include ulow and ulow_rot.

- Water depth at the STTM has been calculated using the depth data
  from the upward-looking Teledyne RDI V20 Sentinel ADCP. The V20 was
  upward-looking on the STTM, but the data is only being used to
  calculate depth of the STTM

- `dat['vel']` has been updated to be: `vel = velraw + velrot + velacc - ulow_bt + ulow_rot`

- TurbBinner has been used to calculate 5-minute means for ADV in ETU
  (East, True North, Up)

- TurbBinner has been used to calculate 5-minute means for
  SMBworkhorse in ETU (East, True North, Up)

- Raw file has been imported from the port Vector. No additional
  processing to these data have been performed.

- Some of the the Starboard Vector variables have been exported to
  .csv

## Mobile Transects

A ship-mounted, downward looking 300kHz ADCP data was used to conduct
the mobile transect survey in the Western Passage, on the border of
Maine, USA, and New Brunswick, Canada. The data was collected April 5
and 6, 2017. The transects target three lines, defined by the
following points (A to B):

- Line 1: `66° 59.561 W', 44° 55.268' N` to `66° 59.267 W', 44° 55.477' N` 
- Line 2: `66° 59.422 W', 44° 55.185' N` to `66° 59.125 W', 44° 55.395' N` 
- Line 3: `66° 59.281 W', 44° 55.101' N` to `66° 59.984 W', 44° 55.309' N` 

There are a total of 86 transects in this folder. 42 transects were
made on April 5, and 44 on April 6. The
`WP2017_MobileTransect_LOG.xlsx` file catalogues the time and
target-transect of each file (including direction denoted by "B-A" or
"A-B"). All timestamps (in the log and in the data files) are in Maine
local time (UTC-4).

### Mobile Transects Data Files

All mobile transect data is contained in the
`WP2017_MobileTransect_RDI300_ALLDATA.zip` file. Within that file, the
data is organized as described below.

The transect data files have the following naming convention:

    WP2017_MobileTransect_RDI300_###.<ext>

Where `###` indicates the transect number, and `.<ext>` is one of the
following file extensions:

- `.PD0` files are the source RDI ADCP files. See the RDI
  documentation for details on this file format.

- `.h5` contain all of the data after processing.

- `.csv.zip` files are the processed data in a set of csv files that
  have been zipped together into a single zip file. The zip files
  contain the following files:

  - `WP2017_MobileTransect_RDI300_###.EAST.csv`, magnetic eastward
    velocity component, units: m/s. Columns are depth bins, with the
    headers indicating the depth in m. Rows are timesteps.

  - `WP2017_MobileTransect_RDI300_###.NORTH.csv`, magnetic northward
      velocity component. Format the same as `.EAST.csv`

  - `WP2017_MobileTransect_RDI300_###.UP.csv`, upward velocity
    component, units: m/s. Format the same as `.EAST.csv`

  - `WP2017_MobileTransect_RDI300_###.ERROR.csv`: RDI-defined error
    velocity, units: m/s. Format the same as `.EAST.csv`

  - `WP2017_MobileTransect_RDI300_###.INFO.csv`: Latitude (`Lat`),
    Longitude (`Long`), bottom depth in meters (`bottom_m`),
    temperature measured at the instrument head in degrees C (`temp_C`).

### Mobile Transects Data Processing

A complete description of data processing can be found in `process_transects.py`. 
A summary is:

- Ship motion velocity subtracted from measurements

- Data has been cleared (i.e., "NaN'd") below 90% of the water depth

- Apply an 11-timestep by 11-depth bin median filter to the data. This
  heavy filtering was applied because the data is very noisy in many
  transects, especially below ~30 m

- Set bottom velocity to zero

- Fill gaps in the data both vertically and temporally

## Additional Data

- `WP2017_TideMet_NDBC_PSBM1.mat` is a MATLAB file of tidal height and
  meteorological measurements created using data from NDBC Station
  [PSBM1 - 8410140 - Eastport, ME](https://www.ndbc.noaa.gov/station_history.php?station=psbm1).

- `wp2017_processing.zip` contains the Python scripts that were
  used to process the data.

- Link to `DOLfYN 0.11.2` is the version of dolfyn used for processing this data.
